@@ -323,15 +323,17 @@ disclaimersContent <- function(appType = "base"){
 #' @export
 #'
 disclaimerUSGS <- function(){
-  "This software is preliminary or provisional and is subject to revision.
-  It is being provided to meet the need for timely best science. The
-  software has not received final approval by the U.S. Geological Survey
-  (USGS). No warranty, expressed or implied, is made by the USGS or the U.S.
-  Government as to the functionality of the software and related material
-  nor shall the fact of release constitute any such warranty. The software
-  is provided on the condition that neither the USGS nor the U.S. Government
-  shall be held liable for any damages resulting from the authorized or
-  unauthorized use of the software."
+  "This is an incremental update to GenEst v1.0.0 which was approved for release
+  by the U.S. Geological Survey (USGS) after rigorous review in compliance with
+  US Geological Survey publishing and associated with IP-101457. This update is
+  preliminary or provisional and is subject to revision. It is being provided to
+  meet the need for timely best science. The update has not received final
+  approval by the U.S. Geological Survey (USGS). No warranty, expressed or
+  implied, is made by the USGS or the U.S. Government as to the functionality of
+  the software and related material nor shall the fact of release constitute any
+  such warranty. The software is provided on the condition that neither the USGS
+  nor the U.S. Government shall be held liable for any damages resulting from
+  the authorized or unauthorized use of the software."
 #  "This software has been approved for release by the U.S. Geological
 #  Survey (USGS). Although the software has been subjected to rigorous
 #  review, the USGS reserves the right to update the software as needed
